======
NAOBot
======

.. image:: https://img.shields.io/travis/evenmarbles/naobot.svg
        :target: https://travis-ci.org/evenmarbles/naobot

.. image:: https://img.shields.io/pypi/v/naobot.svg
        :target: https://pypi.python.org/pypi/naobot


Control for NAO robot

* Free software: BSD license
* Documentation: https://naobot.readthedocs.org.

Features
--------

* TODO
